==> apache-cxf-3.2.12-src.zip: apache-cxf-3.2.12-src/systests/databinding/src/test/java/org/apache/cxf/systest/jaxb/service/ErrorData.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.jaxb.service;

import javax.xml.bind.annotation.XmlType;

@XmlType(name = "ErrorData")
public class ErrorData implements java.io.Serializable {
    private static final long serialVersionUID = 1L;
    private long code;
    private String title;
    private String description;

    public ErrorData() {
    }

    public ErrorData(long code, String title, String description, String stack) {
        this.code = code;
        this.title = title;
        this.description = description;
    }

    public long getCode() {
        return code;
    }

    public void setCode(long code) {
        this.code = code;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
}

==> apache-cxf-3.5.9-src.zip: apache-cxf-3.5.9-src/systests/databinding/src/test/java/org/apache/cxf/systest/jaxb/service/ErrorData.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.systest.jaxb.service;

import javax.xml.bind.annotation.XmlType;

@XmlType(name = "ErrorData")
public class ErrorData implements java.io.Serializable {
    private static final long serialVersionUID = 1L;
    private long code;
    private String title;
    private String description;

    public ErrorData() {
    }

    public ErrorData(long code, String title, String description) {
        this.code = code;
        this.title = title;
        this.description = description;
    }

    public long getCode() {
        return code;
    }

    public void setCode(long code) {
        this.code = code;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
}
